Package overview
================

.. automodule:: paule

Submodules
----------

.. automodule:: paule.grad_plan
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: paule.models
    :members:
    :undoc-members:
    :show-inheritance:

